local addonName = ...
local addon = _G[addonName]

local aceConfig = LibStub("AceConfig-3.0")
local aceConfigReg = LibStub("AceConfigRegistry-3.0")
local aceConfigDia = LibStub("AceConfigDialog-3.0")

local TURQUOISE = "|cFF40E0D0"
local ORANGE = "|cFFFFA500"

-- Get the profile information from SavedVariables
local function getProfiles()
   return LibStub("AceDBOptions-3.0"):GetOptionsTable(addon.db)
end

local commands
local function slashCommands()
   if not commands then
      commands = {
         name = "sg",
         type = "group",
         args = {
            show = {
               name = "show",
               desc = "Opens the SkillGuide panel",
               type = "execute",
               func = function() addon.frame:Show() end
            },
            hide = {
               name = "hide",
               desc = "Hides the SkillGuide panel",
               type = "execute",
               func = function() addon.frame:Hide() end
            }
         }
      }
   end

   return commands
end

local general
local function generalOpts()
   if not general then
      general = {
         name = "General",
         desc = "General Options",
         type = "group",
         args = {
            refresh = {
               name = "Refresh",
               desc = "Refresh rate of the list of best recipes to make, decrease to improve performance",
               type = "range",
               min  = 1,
               max  = 100,
               set  = function(info, value) addon.db.global.upm = value end,
               get  = function() return addon.db.global.upm end
            }
         }
      }
   end
   
   return general
end

local options
local function fullOptions()
   if not options then
      
      options = {
         name = addonName,
         desc = "Configuation options for " .. addonName,
         type = "group",
         args = {
            faq_header = {
               name = "FAQ",
               desc = "Frequently Asked Questions",
               type = "header",
               order = 1
            },
            faq_q1 = {
               name = TURQUOISE .. "Q: What is SkillGuide used for?",
               desc = "Question 1 of the FAQ",
               type = "description",
               order = 2
            },
            faq_a1 = {
               name = ORANGE .. "A: SkillGuide is an in-game tradeskill guide used for both power leveling or leveling any trade skill.",
	       desc = "Answer 1 of the FAQ",
               type = "description",
               order = 3
            },
            spacer_1 = {
               name = "\n",
               desc = "spacer",
               type = "description",
               order = 4
            },
            faq_q2 = {
               name = TURQUOISE .. "Q: How does this differ from a browser guide such as wow-professions.com?",
               desc = "Question 1 of the FAQ",
               type = "description",
               order = 5
            },
            faq_a2 = {
               name = ORANGE .. "A: Browser guides are the suggested route someone should take if they want to power level and either have the gold to buy the mats or the time to farm them. These are commonly the opinion of the author and if you didn't, or couldn't, aquire the same recipes then you must figure out for yourself how to get those few skill ups your self. SkillGuide looks at the recipes you currently own and uses a series of calculatons to find the \"cheapest\" skill up possible. If you have no recipes that can provide a skill up, then it will point you to either a trainer or a vender that has the optimal recipe.",
	       desc = "Answer 1 of the FAQ",
               type = "description",
               order = 6
            },
            spacer_2 = {
               name = "\n",
               desc = "spacer",
               type = "description",
               order = 7
            },
            faq_q3 = {
               name = TURQUOISE .. "Q: what happens when a new recipe or tradeskill is added? Do I have to wait for you to update to be told about these recipes?",
               desc = "Question 1 of the FAQ",
               type = "description",
               order = 8
            },
            faq_a3 = {
               name = ORANGE .. "A: SkillGuide learns new recipes as you do. Since you can't skill up on something you haven't learned, why bother including it in the calculations?",
	       desc = "Answer 1 of the FAQ",
               type = "description",
               order = 9
            },
         }
      }
   end
   
   return options
end

function addon:SetupOptions() 
   -- register the commnds table with AceConfig
   aceConfigReg:RegisterOptionsTable(addonName .. "Cmds", slashCommands())  

   aceConfigReg:RegisterOptionsTable(addonName, fullOptions())
   self.optionsFrame = aceConfigDia:AddToBlizOptions(addonName)
   
--   aceConfigReg:RegisterOptionsTable(addonName .. "General", generalOpts())
--   self.optionsFrame["General"] = aceConfigDia:AddToBlizOptions(addonName .. "General", "General", addonName .. "Options", addonName .. "General")
   
   -- add the sub information to the configuration dialog
--   aceConfigReg:RegisterOptionsTable(addonName, generalOpts())
--   self.optionsFrame["General"] = aceConfigDia:AddToBlizOptions(addonName, "General", addonName, "general");
--   self:RegisterModuleOptions("Profiles", getProfiles(), "Profiles")
   
   -- add about panel to Bliz options
   if LibStub:GetLibrary("LibAboutPanel", true) then
      self.optionsFrame["About"] = LibStub:GetLibrary("LibAboutPanel").new(addonName, addonName)
   else
      self:Print("LibAboutPanel not loaded")
   end
   
end
